from aliot.aliot_obj import AliotObj
from test_state import TestState

test = AliotObj("test")

# the state of your object should be defined in this class
test_state = TestState()


# write your listeners and receivers here


def start():
    # write the code you want to execute once your object is connected to the server
    pass


def end():
    # write the code you want to execute once your object is disconnected from the server
    pass


test.on_start(callback=start)
test.on_end(callback=end)
test.run()  # connects your object to the sever



class ShouldNotCallError(Exception):
    def __init__(self, msg: str = ""):
        super(ShouldNotCallError, self).__init__(msg)

    @staticmethod
    def wrap_do_not_call_error(msg: str):
        return lambda *a, **k: ShouldNotCallError(msg).__raise()

    def __raise(self):
        raise self



import json
from dataclasses import fields, Field


class AliotObjState:
    def as_doc(self, document_name="document"):
        if not hasattr(self, "__dataclass_fields__"):
            # if the child object is not a dataclass, we return the object as a dict formatted with the document name
            return {f"/{document_name}/{key}": val for key, val in self.__dict__.items()}

        def field_is_included(field: Field):
            # returns True if the metadata does not contain "as_doc" or if it contains "as_doc" and it is True
            return field.metadata.get("as_doc", True)

        # noinspection PyDataclass
        return {f"/{document_name}/{field.name}": getattr(self, field.name) for field in fields(self) if
                field_is_included(field)}

    def __str__(self):
        return json.dumps(self.__dict__, indent=2)



import os
from configparser import DuplicateSectionError
from typing import Optional

from aliot.core._config.constants import CONFIG_FILE_NAME, DEFAULT_FOLDER, DEFAULT_CONFIG_FILE_PATH
from aliot.core._config.config import make_config_section, get_default_code
from aliot.core._config.config import update_config, config_init, get_config
from aliot.core._config.templates import from_template


def make_init(folder: str):
    """Makes the _config.ini"""
    os.makedirs(folder, exist_ok=True)
    path = f"{folder}/{CONFIG_FILE_NAME}"
    if os.path.exists(path):
        return False, "Config file already exists"
    try:
        config_init(path)
    except ValueError as e:
        return None, f"Could not create config file: {e!r}"
    return True, None


def make_obj(obj_name: str, template: str = "complete", main_name: str = None):
    if main_name is None:
        main_name = obj_name
    path = f"{DEFAULT_FOLDER}/{obj_name}"
    if os.path.exists(path):
        return False, "Object already exists"
    try:
        os.makedirs(path, exist_ok=True)
        with open(f"{path}/{main_name}.py", "w+") as f:
            f.write(from_template(template, obj_name, path))
    except FileNotFoundError:
        return None, f"Could not create object script at {path!r}"

    return True, None


def make_obj_config(obj_name: str, fields_to_overwrite: dict = None):
    if fields_to_overwrite is None:
        fields_to_overwrite = {}
    try:
        config = get_config(DEFAULT_CONFIG_FILE_PATH)
        config.add_section(obj_name)
        tmp_dict = make_config_section(obj_name)
        tmp_dict.update(fields_to_overwrite)
        config[obj_name] = tmp_dict
        update_config(DEFAULT_CONFIG_FILE_PATH, config)
    except (ValueError, DuplicateSectionError) as e:
        return False, f"Could not update config file: {e!r}"
    except FileNotFoundError:
        return (
            None,
            f"Could not find config file at {DEFAULT_CONFIG_FILE_PATH!r} (try running `aliot init)`",
        )

    return True, None



import pathlib

from setuptools import find_packages, setup
import aliot

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

if __name__ == "__main__":
    setup(name='aliot-py',
          author='Mathis Laroche, Enric Soldevila',
          author_email="alivecode.developers@gmail.com",
          version=aliot.__version__,
          description='Aliot-py is the python implementation of the Aliot library, an'
                      ' IOT library made to work with the ALIVEIoT ecosystem (see https://alivecode.ca/iot)',
          long_description=README,
          long_description_content_type="text/markdown",
          classifiers=[
              "Programming Language :: Python :: 3",
              "Programming Language :: Python :: 3.7",
          ],
          url="https://github.com/ALIVEcode/aliot/tree/aliot2",
          packages=find_packages(
              include=['aliot', 'aliot.*']),
          include_package_data=True,
          python_requires=">=3.7",
          install_requires=["websocket-client~=1.3.2",
                            "rich~=12.3.0",
                            "click~=8.1.3",
                            "requests~=2.27.1",
                            "setuptools==62.1.0"
                            ],
          setup_requires="setuptools",
          entry_points={
              "console_scripts": ["aliot = aliot.core._cli.aliot_cli:main"]
          },
          )
